@@ -1,32 +1,20 @@
-/* === This file is part of Calamares - <https://github.com/calamares> ===
+/* === This file is part of Calamares - <https://calamares.io> ===
  *
  *   SPDX-FileCopyrightText: 2010-2011 Christian Muehlhaeuser <muesli@tomahawk-player.org>
  *   SPDX-FileCopyrightText: 2014 Teo Mrnjavac <teo@kde.org>
  *   SPDX-FileCopyrightText: 2017 Adriaan de Groot <groot@kde.org>
- *
- *
- *   Calamares is free software: you can redistribute it and/or modify
- *   it under the terms of the GNU General Public License as published by
- *   the Free Software Foundation, either version 3 of the License, or
- *   (at your option) any later version.
- *
- *   Calamares is distributed in the hope that it will be useful,
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- *   GNU General Public License for more details.
- *
- *   You should have received a copy of the GNU General Public License
- *   along with Calamares. If not, see <http://www.gnu.org/licenses/>.
- *
  *   SPDX-License-Identifier: GPL-3.0-or-later
- *   License-Filename: LICENSE
+ *
+ *
+ *   Calamares is Free Software: see the License-Identifier above.
+ *
  *
  */
 
 #include "Logger.h"
 
-#include <fstream>
-#include <iostream>
+#include "CalamaresVersionX.h"
+#include "utils/Dirs.h"
 
 #include <QCoreApplication>
 #include <QDir>
@@ -35,10 +23,10 @@
 #include <QTime>
 #include <QVariant>
 
-#include "CalamaresVersion.h"
-#include "utils/Dirs.h"
+#include <fstream>
+#include <iostream>
 
-#define LOGFILE_SIZE 1024 * 256
+static constexpr const int LOGFILE_SIZE = 1024 * 256;
 
 static std::ofstream logfile;
 static unsigned int s_threshold =
@@ -190,11 +178,11 @@ CDebug::CDebug( unsigned int debugLevel, const char* func )
 {
     if ( debugLevel <= LOGERROR )
     {
-        m_msg = QStringLiteral( "ERROR:" );
+        m_msg = QStringLiteral( "ERROR: " );
     }
     else if ( debugLevel <= LOGWARNING )
     {
-        m_msg = QStringLiteral( "WARNING:" );
+        m_msg = QStringLiteral( "WARNING: " );
     }
 }
 
