@@ -110,7 +110,7 @@ updatePreview( Job* job, const std::true_type& )
 
 template < typename Job >
 void
-updatePreview( Job* job, const std::false_type& )
+updatePreview( Job*, const std::false_type& )
 {
 }
 
@@ -483,7 +483,6 @@ PartitionCoreModule::deletePartition( Device* device, Partition* partition )
         }
     }
 
-    const Calamares::JobList& jobs = deviceInfo->jobs();
     if ( partition->state() == KPM_PARTITION_STATE( New ) )
     {
         // Take all the SetPartFlagsJob from the list and delete them
@@ -717,6 +716,8 @@ PartitionCoreModule::updateIsDirty()
 void
 PartitionCoreModule::scanForEfiSystemPartitions()
 {
+    const bool wasEmpty = m_efiSystemPartitions.isEmpty();
+
     m_efiSystemPartitions.clear();
 
     QList< Device* > devices;
@@ -733,6 +734,11 @@ PartitionCoreModule::scanForEfiSystemPartitions()
     {
         cWarning() << "system is EFI but no EFI system partitions found.";
     }
+    else if ( wasEmpty )
+    {
+        // But it isn't empty anymore, so whatever problem has been solved
+        cDebug() << "system is EFI and new EFI system partition has been found.";
+    }
 
     m_efiSystemPartitions = efiSystemPartitions;
 }
@@ -862,81 +868,9 @@ PartitionCoreModule::setBootLoaderInstallPath( const QString& path )
 }
 
 void
-PartitionCoreModule::initLayout()
+PartitionCoreModule::initLayout( FileSystem::Type defaultFsType, const QVariantList& config )
 {
-    m_partLayout = new PartitionLayout();
-
-    m_partLayout->addEntry( QString( "/" ), QString( "100%" ) );
-}
-
-void
-PartitionCoreModule::initLayout( const QVariantList& config )
-{
-    bool ok;
-    QString sizeString;
-    QString minSizeString;
-    QString maxSizeString;
-
-    m_partLayout = new PartitionLayout();
-
-    for ( const auto& r : config )
-    {
-        QVariantMap pentry = r.toMap();
-
-        if ( !pentry.contains( "name" ) || !pentry.contains( "mountPoint" ) || !pentry.contains( "filesystem" )
-             || !pentry.contains( "size" ) )
-        {
-            cError() << "Partition layout entry #" << config.indexOf( r )
-                     << "lacks mandatory attributes, switching to default layout.";
-            delete ( m_partLayout );
-            initLayout();
-            break;
-        }
-
-        if ( pentry.contains( "size" ) && CalamaresUtils::getString( pentry, "size" ).isEmpty() )
-        {
-            sizeString.setNum( CalamaresUtils::getInteger( pentry, "size", 0 ) );
-        }
-        else
-        {
-            sizeString = CalamaresUtils::getString( pentry, "size" );
-        }
-
-        if ( pentry.contains( "minSize" ) && CalamaresUtils::getString( pentry, "minSize" ).isEmpty() )
-        {
-            minSizeString.setNum( CalamaresUtils::getInteger( pentry, "minSize", 0 ) );
-        }
-        else
-        {
-            minSizeString = CalamaresUtils::getString( pentry, "minSize" );
-        }
-
-        if ( pentry.contains( "maxSize" ) && CalamaresUtils::getString( pentry, "maxSize" ).isEmpty() )
-        {
-            maxSizeString.setNum( CalamaresUtils::getInteger( pentry, "maxSize", 0 ) );
-        }
-        else
-        {
-            maxSizeString = CalamaresUtils::getString( pentry, "maxSize" );
-        }
-
-        if ( !m_partLayout->addEntry( CalamaresUtils::getString( pentry, "name" ),
-                                      CalamaresUtils::getString( pentry, "uuid" ),
-                                      CalamaresUtils::getString( pentry, "type" ),
-                                      CalamaresUtils::getUnsignedInteger( pentry, "attributes", 0 ),
-                                      CalamaresUtils::getString( pentry, "mountPoint" ),
-                                      CalamaresUtils::getString( pentry, "filesystem" ),
-                                      CalamaresUtils::getSubMap( pentry, "features", ok ),
-                                      sizeString,
-                                      minSizeString,
-                                      maxSizeString ) )
-        {
-            cError() << "Partition layout entry #" << config.indexOf( r ) << "is invalid, switching to default layout.";
-            delete ( m_partLayout );
-            initLayout();
-            break;
-        }
-    }
+    m_partLayout.init( defaultFsType, config );
 }
 
 void
@@ -948,7 +882,8 @@ PartitionCoreModule::layoutApply( Device* dev,
                                   const PartitionRole& role )
 {
     bool isEfi = PartUtils::isEfiSystem();
-    QList< Partition* > partList = m_partLayout->execute( dev, firstSector, lastSector, luksPassphrase, parent, role );
+    QList< Partition* > partList
+        = m_partLayout.createPartitions( dev, firstSector, lastSector, luksPassphrase, parent, role );
 
     // Partition::mountPoint() tells us where it is mounted **now**, while
     // PartitionInfo::mountPoint() says where it will be mounted in the target system.
